MNE-NIRS: Near-Infrared Spectroscopy Analysis
=============================================

.. image:: https://img.shields.io/badge/docs-master-brightgreen
    :target: https://mne.tools/mne-nirs/
    
.. image:: https://github.com/mne-tools/mne-nirs/workflows/linux%20/%20pip/badge.svg
    :target: https://github.com/mne-tools/mne-nirs/actions?query=workflow%3A%22linux+%2F+pip%22
    
.. image:: https://github.com/mne-tools/mne-nirs/workflows/macos%20/%20conda/badge.svg
    :target: https://github.com/mne-tools/mne-nirs/actions?query=workflow%3A%22macos+%2F+conda%22
    
.. image:: https://github.com/mne-tools/mne-nirs/workflows/linux%20/%20conda/badge.svg
    :target: https://github.com/mne-tools/mne-nirs/actions?query=workflow%3A%22linux+%2F+conda%22
    
.. image:: https://codecov.io/gh/mne-tools/mne-nirs/branch/master/graph/badge.svg
    :target: https://codecov.io/gh/mne-tools/mne-nirs
    
.. image:: https://badge.fury.io/py/mne-nirs.svg
    :target: https://badge.fury.io/py/mne-nirs

**MNE-NIRS** is an `MNE <https://mne.tools>`_ compatible near-infrared spectroscopy processing package. 

MNE has support for common fNIRS waveform analysis (see `tutorial <https://mne.tools/stable/auto_tutorials/preprocessing/plot_70_fnirs_processing.html>`_), this package adds additional GLM style analysis, helper functions, algorithms, and plotting.


Documentation
-------------

Documentation for this project is hosted `here <https://mne-tools.github.io/mne-nirs>`_.


Examples
--------

- MNE examples:
    - `Basic waveform analysis pipeline <https://mne.tools/dev/auto_tutorials/preprocessing/plot_70_fnirs_processing.html#sphx-glr-auto-tutorials-preprocessing-plot-70-fnirs-processing-py>`_.
    - `Artifact rejection discussion <https://mne.tools/dev/auto_examples/preprocessing/plot_fnirs_artifact_removal.html#ex-fnirs-artifacts>`_.
- MNE-NIRS examples:
    - `Simulated haemodynamic response GLM analysis <https://mne.tools/mne-nirs/auto_examples/plot_11_hrf_simulation.html>`_.
    - `Measured haemodynamic response GLM analysis <https://mne.tools/mne-nirs/auto_examples/plot_10_hrf.html>`_.
    - `Group level GLM analysis <https://mne.tools/mne-nirs/auto_examples/plot_12_group_glm.html>`_.
    - `Signal enhancement <https://mne-tools.github.io/mne-nirs/auto_examples/plot_20_cui.html>`_.
    - `Frequency and filtering <https://mne.tools/mne-nirs/auto_examples/plot_30_frequency.html>`_.


Contributing
------------

Contributions are welcome (more than welcome!). Contributions can be feature requests, improved documentation, bug reports, code improvements, new code, etc. Anything will be appreciated. *Note*: this package adheres to the same contribution  `standards as MNE <https://mne.tools/stable/install/contributing.html>`_.


Acknowledgements
----------------

This package is built on top of many other great packages. If you use MNE-NIRS you should also acknowledge these packages.

MNE: https://mne.tools/dev/overview/cite.html

Nilearn: http://nilearn.github.io/authors.html#citing

statsmodels: https://www.statsmodels.org/stable/index.html#citation

Until there is a journal article specifically on MNE-NIRS, please cite `this article <https://www.biorxiv.org/content/10.1101/2020.12.22.423886v1>`_.
